@@ -9,7 +9,12 @@ import time
 
 def run_cli():
     runner = CliRunner()
-    return runner.invoke(cli, ['serve', pkg_resources.resource_filename('tests', 'resources/test.nt')])
+    return runner.invoke(cli, [
+        'serve', 
+        pkg_resources.resource_filename('tests', 'resources/test.nq'),
+        pkg_resources.resource_filename('tests', 'resources/test2.ttl'),
+        pkg_resources.resource_filename('tests', 'resources/another.jsonld'),
+    ])
 
 
 @pytest.fixture
@@ -24,7 +29,7 @@ def server(scope="module"):
 def test_query_cli(server):
     resp = requests.get('http://0.0.0.0:8000/sparql?query=' + select_all_query, 
         headers={'accept': 'application/json'})
-    assert len(resp.json()['results']['bindings']) > 0
+    assert len(resp.json()['results']['bindings']) > 2
 
 
 select_all_query = """SELECT * WHERE {
